<?php
/**
 *
 * blogshop Latest Post Widgets
 */
class Blogshop_Recent_Posts_Widget extends WP_Widget {

	function __construct() {
		parent::__construct(
			'blogshop-latest-post',
			esc_html__( 'Blogshop Latest Posts', 'blogshop' )
		);
	}

	private $widget_fields = array(
		array(
			'label' => 'Post Count',
			'id' => 'post-count',
			'type' => 'number',
		),
	);

	public function widget( $args, $instance ) {
		echo $args['before_widget'];

		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}

		?>
			<ul class="recent-post-widget">
				<?php
				$post_count = ! empty( $instance['post-count'] ) ? $instance['post-count'] : 5;
				$resent_post    = new WP_Query(
					array(
						'post_type' => array( 'post' ),
						'posts_per_page'    => $post_count,
					)
				);
				while ( $resent_post->have_posts() ) :
					$resent_post->the_post();
					?>
				<li>
					<div class="recent-post-thumb">
						<?php the_post_thumbnail( 'blogshop-thubnail-mobile' ); ?>
					</div>
					<div class="recent-widget-content">
						 <a href="<?php echo esc_url( get_permalink() ); ?>"><h5 class="rct-news-title"><?php the_title(); ?></h5></a>
				  		<p><?php blogshop_posted_by(); ?></p>
					</div>
				</li>
				<?php endwhile; ?>
			</ul>
		<?php

		echo $args['after_widget'];
	}

	public function field_generator( $instance ) {
		$output = '';
		foreach ( $this->widget_fields as $widget_field ) {
			$default = '';
			if ( isset($widget_field['default']) ) {
				$default = $widget_field['default'];
			}
			$widget_value = ! empty( $instance[$widget_field['id']] ) ? $instance[$widget_field['id']] : esc_html__( $default, 'blogshop' );
			switch ( $widget_field['type'] ) {
				default:
					$output .= '<p>';
					$output .= '<label for="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'">'.esc_attr( $widget_field['label'], 'blogshop' ).':</label> ';
					$output .= '<input class="widefat" id="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'" name="'.esc_attr( $this->get_field_name( $widget_field['id'] ) ).'" type="'.$widget_field['type'].'" value="'.esc_attr( $widget_value ).'">';
					$output .= '</p>';
			}
		}
		echo $output;
	}

	public function form( $instance ) {
		$title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( '', 'blogshop' );
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'blogshop' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<?php
		$this->field_generator( $instance );
	}

	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		foreach ( $this->widget_fields as $widget_field ) {
			switch ( $widget_field['type'] ) {
				default:
					$instance[$widget_field['id']] = ( ! empty( $new_instance[$widget_field['id']] ) ) ? strip_tags( $new_instance[$widget_field['id']] ) : '';
			}
		}
		return $instance;
	}
}

function blogshop_recenter_post_widget() {
	register_widget( 'Blogshop_Recent_Posts_Widget' );
}
add_action( 'widgets_init', 'blogshop_recenter_post_widget' );